==> miniworldmaker-2.18.0.0.tar.gz: miniworldmaker-2.18.0.0/miniworldmaker/tools/keys.py <==
from collections.abc import Sequence
from typing import List

import pygame

KEYS = {20: "Q",
        26: "W",
        8: "E",
        21: "R",
        23: "T",
        28: "Z",
        24: "U",
        12: "I",
        18: "O",
        19: "P",
        4: "A",
        22: "S",
        7: "D",
        9: "F",
        10: "G",
        11: "H",
        13: "J",
        14: "K",
        15: "L",
        29: "Y",
        27: "X",
        6: "C",
        25: "V",
        5: "B",
        17: "N",
        16: "M",
        44: "SPACE",
        82: "UP",
        81: "DOWN",
        80: "LEFT",
        79: "RIGHT",
        40: "ENTER",
        225: "L_SHIFT",
        229: "R_SHIFT",
        224: "STRG",
        58: "F1",
        59: "F2",
        60: "F3",
        61: "F4",
        62: "F5",
        63: "F6",
        64: "F7",
        65: "F8",
        66: "F9",
        67: "F10",
        68: "F11",
        41: "ESC",
        42: "BACKSPACE"
        }

mwm_aliases = {
    "return": "ENTER",
    "space": "SPACE",
    "backspace": "BACKSPACE",
}

mwm_strings = {
    "SPACE": " ",
}


def key_codes_to_keys(key_pressed_list: Sequence) -> List:
    keys = []
    for index, item in enumerate(key_pressed_list):
        if item:
            if index in KEYS:
                keys.append(KEYS.get(index))
                keys.append(KEYS.get(index).lower())
    return keys


def event_to_key(key_code, keys_pressed) -> str:
    key = pygame.key.name(key_code)
    if "L_SHIFT" in keys_pressed or "R_SHIFT" in keys_pressed:
        key = key.upper()
    if key in mwm_aliases:  # transform pygame to mwm, e.g. return->ENTER
        key = mwm_aliases[key]
    if key in mwm_strings:  # transform to string
        key = mwm_strings[key]
    return key

==> miniworldmaker-2.18.0.2.tar.gz: miniworldmaker-2.18.0.2/miniworldmaker/tools/keys.py <==
from collections.abc import Sequence
from typing import List

import pygame

KEYS = {20: "Q",
        26: "W",
        8: "E",
        21: "R",
        23: "T",
        28: "Z",
        24: "U",
        12: "I",
        18: "O",
        19: "P",
        4: "A",
        22: "S",
        7: "D",
        9: "F",
        10: "G",
        11: "H",
        13: "J",
        14: "K",
        15: "L",
        29: "Y",
        27: "X",
        6: "C",
        25: "V",
        5: "B",
        17: "N",
        16: "M",
        44: "SPACE",
        82: "UP",
        81: "DOWN",
        80: "LEFT",
        79: "RIGHT",
        40: "ENTER",
        225: "L_SHIFT",
        229: "R_SHIFT",
        224: "STRG",
        58: "F1",
        59: "F2",
        60: "F3",
        61: "F4",
        62: "F5",
        63: "F6",
        64: "F7",
        65: "F8",
        66: "F9",
        67: "F10",
        68: "F11",
        41: "ESC",
        42: "BACKSPACE"
        }

mwm_aliases = {
    "return": "ENTER",
    "space": "SPACE",
    "backspace": "BACKSPACE",
}

mwm_strings = {
    "SPACE": " ",
}

def key_codes_to_keys(key_pressed_list: Sequence) -> List:
    keys = []
    print(key_pressed_list)
    for index, item in enumerate(key_pressed_list):
        if item:
            if index in KEYS:
                keys.append(KEYS.get(index))
                keys.append(KEYS.get(index).lower())
    return keys

def event_to_key(key_code) -> str:
    key = pygame.key.name(key_code)
    keys_pressed = pygame.key.get_pressed()
    if "L_SHIFT" in keys_pressed or "R_SHIFT" in keys_pressed:
        key = key.upper()
    if key in mwm_aliases:  # transform pygame to mwm, e.g. return->ENTER
        key = mwm_aliases[key]
    if key in mwm_strings:  # transform to string
        key = mwm_strings[key]
    return key
